@@ -1,4 +1,4 @@
 from .phrase import Phrase
 from .full_language import FullLanguage
-from .internationalization_file import InternationalizationFile
 from .path_file import PathFile
+from .language_phrase import LanguagePhrase
